@@ -467,7 +467,7 @@ public class MeasureCoords {
             gc.setLineWidth(1);            
             gc.drawLine(fromX + getWidth() - 3 + getSpan(), y1, fromX + getWidth() - 3 + getSpan(), y2);
             
-            gc.drawString("x" + Integer.toString(measure.getNumberOfRepetitions()),fromX + getWidth() - 10,fromY - 5);
+            gc.drawString("x" + Integer.toString(measure.getNumberOfRepetitions()),fromX + getWidth() - 10 + getSpan(),fromY - 5);
         }else if(isLastMeasure()){
             gc.setLineWidth(3);
             gc.drawLine(fromX + getWidth() + getSpan(), y1, fromX + getWidth() + getSpan(), y2);            
@@ -510,7 +510,7 @@ public class MeasureCoords {
     /**
      * Retorna true si se esta reproduciendo y la posicion del player esta en este compas.
      */    
-    private boolean isPlaying(){
+    public boolean isPlaying(){
         if(this.songManager.getPlayer().isRunning()){
             long playerTickPosition = this.songManager.getPlayer().getTickPosition();
             if(playerTickPosition >= getMeasure().getStart()  && playerTickPosition < getMeasure().getStart() + getMeasure().getLength()){            
