@@ -9,6 +9,8 @@ package org.herac.tuxguitar.gui.tab;
 import java.util.Iterator;
 import java.util.List;
 
+import org.eclipse.swt.SWT;
+import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
 import org.herac.tuxguitar.gui.TuxGuitar;
@@ -211,6 +213,7 @@ public class NoteCoords implements MeasureComponent {
         int x = fromX + getPosX() + getSpan();
         int y = fromY + getPosY();
         this.pointX = x;
+        gc.setFont(new Font(tablature.getDisplay(),"Sans", 9, SWT.NORMAL));
         if (getNote().isTiedNote()) {
             NoteCoords noteForTie = getNoteForTie();
             if (noteForTie != null) {
@@ -283,7 +286,6 @@ public class NoteCoords implements MeasureComponent {
      */
     private void paintDuration(GC gc, int fromX, int fromY) {
         int x = fromX + getPosX() + getSpan();
-        int y1 = fromY + getPosY();
         int y2 = fromY + meassureCoords.getHeight() + 25;
 
         paintVerticalLine(gc, fromX, fromY);
@@ -474,8 +476,7 @@ public class NoteCoords implements MeasureComponent {
                         if(nextComponent != null){                 
                             NoteCoords nextNote = (NoteCoords)nextComponent;
                             //int nextX = nextNote.getPosX() + nextFromX;
-                            int nextX = nextNote.getPosX() + nextFromX + meassureCoords.getSpanForComponent(nextNote);
-                            int nextY = y;                            
+                            int nextX = nextNote.getPosX() + nextFromX + meassureCoords.getSpanForComponent(nextNote);                        
                             gc.drawArc(x,y, (nextX - x),-5,45,90);
                         }else{
                             gc.drawArc(x,y,20,-5,45,90);
