@@ -18,6 +18,7 @@ import org.herac.tuxguitar.song.models.Measure;
 import org.herac.tuxguitar.song.models.SongTrack;
 import org.herac.tuxguitar.song.models.Tempo;
 import org.herac.tuxguitar.song.models.TimeSignature;
+import org.herac.tuxguitar.song.models.TrackColor;
 
 /**
  * @author julian
@@ -443,6 +444,11 @@ public class SongTrackCoords {
         measure.setNumberOfRepetitions(numberOfRepetitions);
     }
     
+    public void changeInfo(String name,TrackColor color){         
+        getTrack().setName(name);
+        getTrack().setColor(color);
+    }
+    
     
     public void changeInstrumentStrings(List strings){
         if(strings.size() < getTrack().getStrings().size()){
@@ -459,6 +465,21 @@ public class SongTrackCoords {
         }          
     }
     
+    public void changeInstrument(int instrument,boolean percusion){
+            if(percusion){
+                getTrack().setChannel(this.songManager.getFreeChannel(instrument,percusion));
+                getTrack().setInstrument(instrument);
+                getTrack().setStrings(SongManager.createPercusionStrings());
+            }else{
+                if(getTrack().isPercusionTrack()){
+                    getTrack().setStrings(SongManager.createDefaultInstrumentStrings());
+                }
+                
+                getTrack().setChannel(this.songManager.getFreeChannel(instrument,percusion));
+                getTrack().setInstrument(instrument);            
+            }        
+        
+    }
     
     public int getHeight() {
         return height;
