@@ -24,6 +24,7 @@ import org.herac.tuxguitar.song.models.Song;
 import org.herac.tuxguitar.song.models.SongTrack;
 import org.herac.tuxguitar.song.models.Tempo;
 import org.herac.tuxguitar.song.models.TimeSignature;
+import org.herac.tuxguitar.song.models.TrackColor;
 
 /**
  * @author julian
@@ -125,8 +126,7 @@ public class GP3OutputStream {
                     SongTrack track = (SongTrack) song.getTracks().get(j);
                     Measure measure = (Measure) track.getMeasures().get(i);
 
-                    addMeasureComponents(track.getStrings().size(), measure, tempo);
-                    System.out.println(tempo.getValue());
+                    addMeasureComponents(track.getStrings().size(), measure, tempo);                    
                 }
             }
 
@@ -210,7 +210,7 @@ public class GP3OutputStream {
         //---------------------------------------------
 
         //name
-        writeStringByte("track", 40);
+        writeStringByte(track.getName(), 40);
 
         //numberOfStrings
         writeInt(track.getStrings().size());
@@ -240,7 +240,7 @@ public class GP3OutputStream {
         writeInt(0);
 
         //color
-        writeColor();
+        writeColor(track.getColor());
 
     }
 
@@ -547,13 +547,13 @@ public class GP3OutputStream {
         return channels;
     }
 
-    private void writeColor() throws IOException {
+    private void writeColor(TrackColor color) throws IOException {
         //red
-        writeUnsignedByte(0);
+        writeUnsignedByte(color.getR());
         //green
-        writeUnsignedByte(0);
+        writeUnsignedByte(color.getG());
         //blue
-        writeUnsignedByte(0);
+        writeUnsignedByte(color.getB());
 
         this.outputStream.write(0);
     }
