@@ -19,6 +19,7 @@ import org.herac.tuxguitar.song.models.Song;
 import org.herac.tuxguitar.song.models.SongTrack;
 import org.herac.tuxguitar.song.models.Tempo;
 import org.herac.tuxguitar.song.models.TimeSignature;
+import org.herac.tuxguitar.song.models.TrackColor;
 
 public class GP4InputStream extends InputStream {
     private static final String supportedVersions[] = { "FICHIER GUITAR PRO v4.00", "FICHIER GUITAR PRO v4.06", "FICHIER GUITAR PRO L4.06" };
@@ -318,11 +319,13 @@ public class GP4InputStream extends InputStream {
         return (byte) read();
     }
 
-    private void readColor() throws IOException {
-        int red = readUnsignedByte();
-        int green = readUnsignedByte();
-        int blue = readUnsignedByte();
+    private TrackColor readColor() throws IOException {
+        int r = readUnsignedByte();
+        int g = readUnsignedByte();
+        int b = readUnsignedByte();
         read();
+        
+        return new TrackColor(r,g,b);
     }
 
     private int readInt() throws IOException {
@@ -526,11 +529,11 @@ public class GP4InputStream extends InputStream {
 
         int capo = readInt();
 
-        readColor();
+        TrackColor color = readColor();
 
         Channel channel = parseChannel(tracks, channels, channelIndex);
 
-        return new SongTrack(channel.getChannel(), channel.getInstrument(), new ArrayList(), strings);
+        return new SongTrack(name,channel.getChannel(), channel.getInstrument(), new ArrayList(), strings,color);
     }
 
     private Channel parseChannel(List tracks, List channels, int channelIndex) {
