@@ -24,6 +24,7 @@ import org.herac.tuxguitar.song.models.Song;
 import org.herac.tuxguitar.song.models.SongTrack;
 import org.herac.tuxguitar.song.models.Tempo;
 import org.herac.tuxguitar.song.models.TimeSignature;
+import org.herac.tuxguitar.song.models.TrackColor;
 
 /**
  * @author julian
@@ -222,7 +223,7 @@ public class GP4OutputStream {
         //---------------------------------------------
 
         //name
-        writeStringByte("track", 40);
+        writeStringByte(track.getName(), 40);
 
         //numberOfStrings
         writeInt(track.getStrings().size());
@@ -252,7 +253,7 @@ public class GP4OutputStream {
         writeInt(0);
 
         //color
-        writeColor();
+        writeColor(track.getColor());
 
     }
 
@@ -551,13 +552,13 @@ public class GP4OutputStream {
         return channels;
     }
 
-    private void writeColor() throws IOException {
+    private void writeColor(TrackColor color) throws IOException {
         //red
-        writeUnsignedByte(0);
+        writeUnsignedByte(color.getR());
         //green
-        writeUnsignedByte(0);
+        writeUnsignedByte(color.getG());
         //blue
-        writeUnsignedByte(0);
+        writeUnsignedByte(color.getB());
 
         this.outputStream.write(0);
     }
