@@ -6,7 +6,6 @@
  */
 package org.herac.tuxguitar.play.models.midiplayer;
 
-import java.util.Iterator;
 import java.util.List;
 
 import javax.sound.midi.InvalidMidiDataException;
@@ -70,7 +69,6 @@ public class SongSequence {
         try {
             sequence = new Sequence(Sequence.PPQ, 1);
 
-            Iterator it = this.songManager.getSong().getTracks().iterator();
             for (int trackIdx = 0; trackIdx < this.songManager.getSong().getTracks().size(); trackIdx++) {
                 SongTrack songTrack = (SongTrack) this.songManager.getSong().getTracks().get(trackIdx);
                 createTrack(songTrack,(trackIdx == 0),getFreeChannelForEffect());
